==> mingw-w64-hugo-0.127.0-1.src.tar.zst: hugo-0.127.0/docs/content/en/tools/editors.md <==
---
title: Editor plugins
linkTitle: Editor plugins
description: The Hugo community uses a wide range of tools and has developed plugins for some of the most popular text editors to help automate parts of your workflow.
categories: [developer tools]
keywords: [editor,plugin]
menu:
  docs:
    parent: developer-tools
    weight: 20
weight: 20
toc: true
---

## Visual Studio Code

[Front Matter](https://marketplace.visualstudio.com/items?itemName=eliostruyf.vscode-front-matter)
: Once you go for a static site, you need to think about how you are going to manage your articles. Front matter is a tool that helps you maintain the metadata/front matter of your articles like: creation date, modified date, slug, tile, SEO check, and more.

[Hugo Helper](https://marketplace.visualstudio.com/items?itemName=rusnasonov.vscode-hugo)
: Hugo Helper is a plugin for Visual Studio Code that has some useful commands for Hugo. The source code can be found [here](https://github.com/rusnasonov/vscode-hugo).

[Hugo Language and Syntax Support](https://marketplace.visualstudio.com/items?itemName=budparr.language-hugo-vscode)
: Hugo Language and Syntax Support is a Visual Studio Code plugin for Hugo syntax highlighting and snippets. The source code can be found [here](https://github.com/budparr/language-hugo-vscode).

[Hugo Themer](https://marketplace.visualstudio.com/items?itemName=eliostruyf.vscode-hugo-themer)
: Hugo Themer is an extension to help you while developing themes. It allows you to easily navigate through your theme files.

[Hugofy](https://marketplace.visualstudio.com/items?itemName=akmittal.hugofy)
: Hugofy is a plugin for Visual Studio Code to "make life easier" when developing with Hugo. The source code can be found [here](https://github.com/akmittal/hugofy-vscode).

[Prettier Plugin for Go Templates](https://github.com/NiklasPor/prettier-plugin-go-template)
: Format Hugo templates using this [Prettier](https://prettier.io/) plugin. See [installation instructions](https://discourse.gohugo.io/t/38403).

[Syntax Highlighting for Hugo Shortcodes](https://marketplace.visualstudio.com/items?itemName=kaellarkin.hugo-shortcode-syntax)
: This extension adds some syntax highlighting for Shortcodes, making visual identification of individual pieces easier.

## Emacs

[emacs-easy-hugo](https://github.com/masasam/emacs-easy-hugo)
: Emacs major mode for managing hugo blogs. Note that Hugo also supports [Org-mode][formats].

[ox-hugo.el](https://ox-hugo.scripter.co)
: Native Org-mode exporter that exports to Blackfriday Markdown with Hugo front-matter. `ox-hugo` supports two common Org blogging flows --- exporting multiple Org subtrees in a single file to multiple Hugo posts, and exporting a single Org file to a single Hugo post. It also leverages the Org tag and property inheritance features. See [*Why ox-hugo?*](https://ox-hugo.scripter.co/doc/why-ox-hugo/) for more.

## Sublime Text

[Hugofy](https://github.com/akmittal/Hugofy)
: Hugofy is a plugin for Sublime Text 3 to make life easier to use Hugo static site generator.

[Hugo Snippets](https://packagecontrol.io/packages/Hugo%20Snippets)
: Hugo Snippets is a useful plugin for adding automatic snippets to Sublime Text&nbsp;3.

## Vim

[Vim Hugo Helper]: https://github.com/robertbasic/vim-hugo-helper

[Vim Hugo Helper]
: A small Vim plugin that facilitates authoring pages and blog posts with Hugo.

[xxx]: xxx

[vim-hugo](https://github.com/phelipetls/vim-hugo)
: A Vim plugin with syntax highlighting for templates and a few other features.

[formats]: /content-management/formats/

==> mingw-w64-hugo-0.148.0-1.src.tar.zst: hugo-0.148.0/docs/content/en/tools/editors.md <==
---
title: Editor plugins
description: The Hugo community uses a wide range of tools and has developed plugins for some of the most popular text editors to help automate parts of your workflow.
categories: []
keywords: []
weight: 10
---

## Visual Studio Code

[Front Matter](https://marketplace.visualstudio.com/items?itemName=eliostruyf.vscode-front-matter)
: Once you go for a static site, you need to think about how you are going to manage your articles. Front matter is a tool that helps you maintain the metadata/front matter of your articles like: creation date, modified date, slug, tile, SEO check, and more.

[Hugo Helper](https://marketplace.visualstudio.com/items?itemName=rusnasonov.vscode-hugo)
: Hugo Helper is a plugin for Visual Studio Code that has some useful commands for Hugo. The source code can be found [here](https://github.com/rusnasonov/vscode-hugo).

[Hugo Language and Syntax Support](https://marketplace.visualstudio.com/items?itemName=budparr.language-hugo-vscode)
: Hugo Language and Syntax Support is a Visual Studio Code plugin for Hugo syntax highlighting and snippets. The source code can be found [here](https://github.com/budparr/language-hugo-vscode).

[Hugo Themer](https://marketplace.visualstudio.com/items?itemName=eliostruyf.vscode-hugo-themer)
: Hugo Themer is an extension to help you while developing themes. It allows you to easily navigate through your theme files.

[Hugofy](https://marketplace.visualstudio.com/items?itemName=akmittal.hugofy)
: Hugofy is a plugin for Visual Studio Code to "make life easier" when developing with Hugo. The source code can be found [here](https://github.com/akmittal/hugofy-vscode).

[Prettier Plugin for Go Templates](https://github.com/NiklasPor/prettier-plugin-go-template)
: Format Hugo templates using this [Prettier](https://prettier.io/) plugin. See [installation instructions](https://discourse.gohugo.io/t/38403).

[Syntax Highlighting for Hugo Shortcodes](https://marketplace.visualstudio.com/items?itemName=kaellarkin.hugo-shortcode-syntax)
: This extension adds some syntax highlighting for Shortcodes, making visual identification of individual pieces easier.

## Emacs

[emacs-easy-hugo](https://github.com/masasam/emacs-easy-hugo)
: Emacs major mode for managing hugo blogs. Note that Hugo also supports [Org-mode][formats].

[ox-hugo.el](https://ox-hugo.scripter.co)
: Native Org-mode exporter that exports to Blackfriday Markdown with Hugo front-matter. `ox-hugo` supports two common Org blogging flows --- exporting multiple Org subtrees in a single file to multiple Hugo posts, and exporting a single Org file to a single Hugo post. It also leverages the Org tag and property inheritance features. See [*Why ox-hugo?*](https://ox-hugo.scripter.co/doc/why-ox-hugo/) for more.

## Sublime Text

[Hugofy](https://github.com/akmittal/Hugofy)
: Hugofy is a plugin for Sublime Text 3 to make life easier to use Hugo static site generator.

[Hugo Snippets](https://packagecontrol.io/packages/Hugo%20Snippets)
: Hugo Snippets is a useful plugin for adding automatic snippets to Sublime Text&nbsp;3.

## Vim

[Vim Hugo Helper]: https://github.com/robertbasic/vim-hugo-helper

[Vim Hugo Helper]
: A small Vim plugin that facilitates authoring pages and blog posts with Hugo.

[vim-hugo](https://github.com/phelipetls/vim-hugo)
: A Vim plugin with syntax highlighting for templates and a few other features.

[formats]: /content-management/formats/
